@@ -13,7 +13,8 @@
 
 package com.verisign.epp.codec.coaext;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.Text;
@@ -22,7 +23,7 @@ import com.verisign.epp.codec.gen.EPPCodecComponent;
 import com.verisign.epp.codec.gen.EPPCodecException;
 import com.verisign.epp.codec.gen.EPPDecodeException;
 import com.verisign.epp.codec.gen.EPPEncodeException;
-import com.verisign.epp.util.EPPCatFactory;
+
 
 /**
  * EPPCodecComponent that encodes and decodes a COA Value Tag.
@@ -52,12 +53,9 @@ public class EPPCoaExtValue implements EPPCodecComponent {
 	private static final long serialVersionUID = 1L;
 
 	/**
-	 * Log4j category for logging
+	 * Category for logging
 	 */
-	private static Logger cat =
-			Logger.getLogger( EPPCoaExtValue.class.getName(), EPPCatFactory
-					.getInstance()
-					.getFactory() );
+	private static Logger cat = LoggerFactory.getLogger(EPPCoaExtValue.class);
 
 	/**
 	 * Constant for the COA value tag
@@ -151,8 +149,8 @@ public class EPPCoaExtValue implements EPPCodecComponent {
 	/**
 	 * Decode the EPPCoaExtValue component
 	 * 
-	 * @param aElement
-	 * @throws EPPDecodeException
+	 * @param aElement DOM Element to decode
+	 * @throws EPPDecodeException On decoding error
 	 */
 	public void decode ( Element aElement ) throws EPPDecodeException {
 
