@@ -38,35 +38,32 @@ import com.verisign.epp.codec.gen.EPPUtil;
  * &lt;contact:update&gt; element SHALL contain the following child elements:
  * <br>
  * <br>
- * 
+ *
  * <ul>
  * <li>A &lt;contact:id&gt; element that contains the server-unique identifier
- * of the contact object to be updated. Use <code>getId</code> and
- * <code>setId</code> to get and set the element.</li>
+ * of the contact object to be updated. Use {@code getId} and {@code setId} to
+ * get and set the element.</li>
  * <li>An OPTIONAL &lt;contact:add&gt; element that contains attribute values to
- * be added to the host object. Use <code>getAdd</code> and <code>setAdd</code>
- * to get and set the element.</li>
+ * be added to the host object. Use {@code getAdd} and {@code setAdd} to get and
+ * set the element.</li>
  * <li>An OPTIONAL &lt;contact:rem&gt; element that contains attribute values to
- * be removed from the host object. Use <code>getRemove</code> and
- * <code>setRemove</code> to get and set the element.</li>
+ * be removed from the host object. Use {@code getRemove} and {@code setRemove}
+ * to get and set the element.</li>
  * <li>An OPTIONAL &lt;contact:chg&gt; element that contains attribute values to
- * be changed to the host object. Use <code>getChange</code> and
- * <code>setChange</code> to get and set the element.</li>
+ * be changed to the host object. Use {@code getChange} and {@code setChange} to
+ * get and set the element.</li>
  * </ul>
- * 
- * <br>
- * <code>EPPReponse</code> is the response associated with
- * <code>EPPContactUpdateCmd</code>. <br>
- * <br>
  *
- * @author $Author: jim $
- * @version $Revision: 1.2 $
+ * <br>
+ * {@code EPPReponse} is the response associated with
+ * {@code EPPContactUpdateCmd}. <br>
+ * <br>
  *
  * @see com.verisign.epp.codec.gen.EPPResponse
  * @see com.verisign.epp.codec.contact.EPPContactAddChange
  */
 public class EPPContactUpdateCmd extends EPPUpdateCmd {
-	/** XML Element Name of <code>EPPHostUpdateCmd</code> root element. */
+	/** XML Element Name of {@code EPPHostUpdateCmd} root element. */
 	final static String ELM_NAME = "contact:update";
 
 	/** XML Element Name for the name attribute. */
@@ -88,17 +85,15 @@ public class EPPContactUpdateCmd extends EPPUpdateCmd {
 	private static Logger cat = LoggerFactory.getLogger(EPPContactUpdateCmd.class);
 
 	/**
-	 * <code>EPPContactUpdateCmd</code> default constructor. The name is
-	 * initialized to <code>null</code>. The name must be set before invoking
-	 * <code>encode</code>.
+	 * {@code EPPContactUpdateCmd} default constructor. The name is initialized
+	 * to {@code null}. The name must be set before invoking {@code encode}.
 	 */
 	public EPPContactUpdateCmd() {
 	}
 
-	// End EPPContactUpdateCmd.EPPContactUpdateCmd()
 
 	/**
-	 * <code>EPPContactUpdateCmd</code> constructor.
+	 * {@code EPPContactUpdateCmd} constructor.
 	 *
 	 * @param aTransId
 	 *           Transaction Id associated with the command.
@@ -108,63 +103,59 @@ public class EPPContactUpdateCmd extends EPPUpdateCmd {
 	public EPPContactUpdateCmd(String aTransId, String aId) {
 		super(aTransId);
 
-		id = aId;
+		this.id = aId;
 	}
 
-	// End EPPContactUpdateCmd.EPPContactUpdateCmd(String, String)
 
 	/**
-	 * <code>EPPContactUpdateCmd</code> constructor that takes the required
-	 * attributes as arguments.
+	 * {@code EPPContactUpdateCmd} constructor that takes the required attributes
+	 * as arguments.
 	 *
 	 * @param aTransId
 	 *           Transaction Id associated with the command.
 	 * @param aId
 	 *           Contact ID.
 	 * @param aAdd
-	 *           Attributes to add to the contact. <code>null</code> if no
-	 *           additions.
+	 *           Attributes to add to the contact. {@code null} if no additions.
 	 * @param aRemove
-	 *           Attributes to remove from the contact. <code>null</code> if no
+	 *           Attributes to remove from the contact. {@code null} if no
 	 *           removals.
 	 * @param aChange
-	 *           Attributes to remove from the contact. <code>null</code> if no
+	 *           Attributes to remove from the contact. {@code null} if no
 	 *           changes.
 	 */
 	public EPPContactUpdateCmd(String aTransId, String aId, EPPContactAddChange aAdd, EPPContactAddChange aRemove,
 	      EPPContactAddChange aChange) {
 		super(aTransId);
 
-		id = aId;
+		this.id = aId;
 
-		add = aAdd;
+		this.add = aAdd;
 
-		if (add != null) {
-			add.setMode(EPPContactAddChange.MODE_ADD);
+		if (this.add != null) {
+			this.add.setMode(EPPContactAddChange.MODE_ADD);
 		}
 
-		remove = aRemove;
+		this.remove = aRemove;
 
-		if (remove != null) {
-			remove.setMode(EPPContactAddChange.MODE_REMOVE);
+		if (this.remove != null) {
+			this.remove.setMode(EPPContactAddChange.MODE_REMOVE);
 		}
 
-		change = aChange;
+		this.change = aChange;
 
-		if (change != null) {
-			change.setMode(EPPContactAddChange.MODE_CHANGE);
+		if (this.change != null) {
+			this.change.setMode(EPPContactAddChange.MODE_CHANGE);
 		}
 	}
 
-	// End EPPContactUpdateCmd.EPPContactUpdateCmd(String, String,
-	// EPPContactAddChange, EPPContactAddChange, EPPContactAddChange)
-
 	/**
 	 * Gets the EPP command Namespace associated with
-	 * <code>EPPContactUpdateCmd</code>.
+	 * {@code EPPContactUpdateCmd}.
 	 *
-	 * @return <code>EPPHostMapFactory.NS</code>
+	 * @return {@code EPPHostMapFactory.NS}
 	 */
+	@Override
 	public String getNamespace() {
 		return EPPContactMapFactory.NS;
 	}
@@ -173,24 +164,24 @@ public class EPPContactUpdateCmd extends EPPUpdateCmd {
 
 	/**
 	 * Encode a DOM Element tree from the attributes of the
-	 * <code>EPPContactUpdateCmd</code> instance.
+	 * {@code EPPContactUpdateCmd} instance.
 	 *
 	 * @param aDocument
 	 *           DOM Document that is being built. Used as an Element factory.
 	 *
-	 * @return Root DOM Element representing the <code>EPPContactUpdateCmd</code>
+	 * @return Root DOM Element representing the {@code EPPContactUpdateCmd}
 	 *         instance.
 	 *
 	 * @exception EPPEncodeException
-	 *               Unable to encode <code>EPPContactUpdateCmd</code> instance.
+	 *               Unable to encode {@code EPPContactUpdateCmd} instance.
 	 */
 	protected Element doEncode(Document aDocument) throws EPPEncodeException {
 		// Validate state
-		if (id == null) {
+		if (this.id == null) {
 			throw new EPPEncodeException("required attribute id is not set");
 		}
 
-		if ((add == null) && (remove == null) && (change == null)) {
+		if ((this.add == null) && (this.remove == null) && (this.change == null)) {
 			throw new EPPEncodeException("at least one from [add, remove, change] needs to be set");
 		}
 
@@ -199,73 +190,71 @@ public class EPPContactUpdateCmd extends EPPUpdateCmd {
 		root.setAttribute("xmlns:contact", EPPContactMapFactory.NS);
 
 		// id
-		EPPUtil.encodeString(aDocument, root, id, EPPContactMapFactory.NS, ELM_CONTACT_ID);
+		EPPUtil.encodeString(aDocument, root, this.id, EPPContactMapFactory.NS, ELM_CONTACT_ID);
 
 		// Add
-		EPPUtil.encodeComp(aDocument, root, add);
+		EPPUtil.encodeComp(aDocument, root, this.add);
 
 		// Remove
-		EPPUtil.encodeComp(aDocument, root, remove);
+		EPPUtil.encodeComp(aDocument, root, this.remove);
 
 		// Change
-		EPPUtil.encodeComp(aDocument, root, change);
+		EPPUtil.encodeComp(aDocument, root, this.change);
 
 		return root;
 	}
 
-	// End EPPContactUpdateCmd.doEncode(Document)
 
 	/**
-	 * Decode the <code>EPPContactUpdateCmd</code> attributes from the aElement
-	 * DOM Element tree.
+	 * Decode the {@code EPPContactUpdateCmd} attributes from the aElement DOM
+	 * Element tree.
 	 *
 	 * @param aElement
-	 *           Root DOM Element to decode <code>EPPContactUpdateCmd</code>
-	 *           from.
+	 *           Root DOM Element to decode {@code EPPContactUpdateCmd} from.
 	 *
 	 * @exception EPPDecodeException
 	 *               Unable to decode aElement
 	 */
 	protected void doDecode(Element aElement) throws EPPDecodeException {
 		// Host Name
-		id = EPPUtil.decodeString(aElement, EPPContactMapFactory.NS, ELM_CONTACT_ID);
+		this.id = EPPUtil.decodeString(aElement, EPPContactMapFactory.NS, ELM_CONTACT_ID);
 
 		// Add
-		add = (EPPContactAddChange) EPPUtil.decodeComp(aElement, EPPContactMapFactory.NS, EPPContactAddChange.ELM_ADD,
-		      EPPContactAddChange.class);
+		this.add = (EPPContactAddChange) EPPUtil.decodeComp(aElement, EPPContactMapFactory.NS,
+		      EPPContactAddChange.ELM_ADD, EPPContactAddChange.class);
 
-		if (add != null) {
-			add.setMode(EPPContactAddChange.MODE_ADD);
+		if (this.add != null) {
+			this.add.setMode(EPPContactAddChange.MODE_ADD);
 		}
 
 		// Remove
-		remove = (EPPContactAddChange) EPPUtil.decodeComp(aElement, EPPContactMapFactory.NS,
+		this.remove = (EPPContactAddChange) EPPUtil.decodeComp(aElement, EPPContactMapFactory.NS,
 		      EPPContactAddChange.ELM_REMOVE, EPPContactAddChange.class);
 
-		if (remove != null) {
-			remove.setMode(EPPContactAddChange.MODE_REMOVE);
+		if (this.remove != null) {
+			this.remove.setMode(EPPContactAddChange.MODE_REMOVE);
 		}
 
 		// Change
-		change = (EPPContactAddChange) EPPUtil.decodeComp(aElement, EPPContactMapFactory.NS,
+		this.change = (EPPContactAddChange) EPPUtil.decodeComp(aElement, EPPContactMapFactory.NS,
 		      EPPContactAddChange.ELM_CHANGE, EPPContactAddChange.class);
 
-		if (change != null) {
-			change.setMode(EPPContactAddChange.MODE_CHANGE);
+		if (this.change != null) {
+			this.change.setMode(EPPContactAddChange.MODE_CHANGE);
 		}
 	}
 
 	// End EPPContactUpdateCmd.doDecode(Node)
 
 	/**
-	 * Compare an instance of <code>EPPContactUpdateCmd</code> with this
-	 * instance.
+	 * Compare an instance of {@code EPPContactUpdateCmd} with this instance.
 	 *
 	 * @param aObject
 	 *           Object to compare with.
 	 *
-	 * @return DOCUMENT ME!
+	 * @return {@code true} if equal; {@code false} otherwise
 	 */
+	@Override
 	public boolean equals(Object aObject) {
 		cat.debug("equals(Object): enter");
 
@@ -282,25 +271,25 @@ public class EPPContactUpdateCmd extends EPPUpdateCmd {
 		EPPContactUpdateCmd theComp = (EPPContactUpdateCmd) aObject;
 
 		// Id
-		if (!((id == null) ? (theComp.id == null) : id.equals(theComp.id))) {
+		if (!((this.id == null) ? (theComp.id == null) : this.id.equals(theComp.id))) {
 			cat.error("equals(Object): id not equal");
 			return false;
 		}
 
 		// Add
-		if (!((add == null) ? (theComp.add == null) : add.equals(theComp.add))) {
+		if (!((this.add == null) ? (theComp.add == null) : this.add.equals(theComp.add))) {
 			cat.error("equals(Object): add not equal");
 			return false;
 		}
 
 		// Remove
-		if (!((remove == null) ? (theComp.remove == null) : remove.equals(theComp.remove))) {
+		if (!((this.remove == null) ? (theComp.remove == null) : this.remove.equals(theComp.remove))) {
 			cat.error("equals(Object): remove not equal");
 			return false;
 		}
 
 		// Change
-		if (!((change == null) ? (theComp.change == null) : change.equals(theComp.change))) {
+		if (!((this.change == null) ? (theComp.change == null) : this.change.equals(theComp.change))) {
 			cat.error("equals(Object): change not equal");
 			return false;
 		}
@@ -312,26 +301,27 @@ public class EPPContactUpdateCmd extends EPPUpdateCmd {
 	// End EPPContactUpdateCmd.equals(Object)
 
 	/**
-	 * Clone <code>EPPContactUpdateCmd</code>.
+	 * Clone {@code EPPContactUpdateCmd}.
 	 *
-	 * @return clone of <code>EPPContactUpdateCmd</code>
+	 * @return clone of {@code EPPContactUpdateCmd}
 	 *
 	 * @exception CloneNotSupportedException
 	 *               standard Object.clone exception
 	 */
+	@Override
 	public Object clone() throws CloneNotSupportedException {
 		EPPContactUpdateCmd clone = (EPPContactUpdateCmd) super.clone();
 
 		if (clone.add != null) {
-			clone.add = (EPPContactAddChange) add.clone();
+			clone.add = (EPPContactAddChange) this.add.clone();
 		}
 
 		if (clone.remove != null) {
-			clone.remove = (EPPContactAddChange) remove.clone();
+			clone.remove = (EPPContactAddChange) this.remove.clone();
 		}
 
 		if (clone.change != null) {
-			clone.change = (EPPContactAddChange) change.clone();
+			clone.change = (EPPContactAddChange) this.change.clone();
 		}
 
 		return clone;
@@ -340,125 +330,143 @@ public class EPPContactUpdateCmd extends EPPUpdateCmd {
 	// End EPPContactUpdateCmd.clone()
 
 	/**
-	 * Implementation of <code>Object.toString</code>, which will result in an
-	 * indented XML <code>String</code> representation of the concrete
-	 * <code>EPPCodecComponent</code>.
+	 * Implementation of {@code Object.toString}, which will result in an
+	 * indented XML {@code String} representation of the concrete
+	 * {@code EPPCodecComponent}.
 	 *
-	 * @return Indented XML <code>String</code> if successful; <code>ERROR</code>
+	 * @return Indented XML {@code String} if successful; {@code ERROR}
 	 *         otherwise.
 	 */
+	@Override
 	public String toString() {
 		return EPPUtil.toString(this);
 	}
 
-	// End EPPContactUpdateCmd.toString()
+	/**
+	 * Returns {@code true} if id exists.
+	 *
+	 * @return {@code true} if id exists; otherwise {@code false}.
+	 */
+	public boolean hasId() {
+		return (this.id != null);
+	}
+	
+	/**
+	 * Gets the contact id.
+	 *
+	 * @return Contact id if set; {@code null} otherwise.
+	 */
+	public String getId() {
+		return this.id;
+	}
+
+	/**
+	 * Sets the contact id.
+	 *
+	 * @param aId
+	 *           Contact id
+	 */
+	public void setId(String aId) {
+		this.id = aId;
+	}
+
+	/**
+	 * Returns {@code true} if add exists.
+	 *
+	 * @return {@code true} if add exists; otherwise {@code false}.
+	 */
+	public boolean hasAdd() {
+		return (this.add != null);
+	}
 
 	/**
 	 * Gets the items to add to the contact.
 	 *
 	 * @return Object that contains the list of elements to add to the contact if
-	 *         defined; <code>null</code> otherwise.
+	 *         defined; {@code null} otherwise.
 	 */
 	public EPPContactAddChange getAdd() {
-		return add;
+		return this.add;
 	}
 
-	// End EPPContactUpdateCmd.getAdd()
+	/**
+	 * Sets the items to add to the contact.
+	 *
+	 * @param aAdd
+	 *          Items to add to the contact.
+	 */
+	public void setAdd(EPPContactAddChange aAdd) {
+		this.add = aAdd;
+
+		if (this.add != null) {
+			this.add.setMode(EPPContactAddChange.MODE_ADD);
+		}
+	}
+
+	/**
+	 * Returns {@code true} if change exists.
+	 *
+	 * @return {@code true} if change exists; otherwise {@code false}.
+	 */
+	public boolean hasChange() {
+		return (this.change != null);
+	}
 
 	/**
 	 * Gets the items to change to the contact.
 	 *
 	 * @return Object that contains the list of elements to change to the contact
-	 *         if defined; <code>null</code> otherwise.
+	 *         if defined; {@code null} otherwise.
 	 */
 	public EPPContactAddChange getChange() {
-		return change;
+		return this.change;
 	}
 
-	// End EPPContactUpdateCmd.getChange()
-
 	/**
-	 * Get contact id.
+	 * Sets the items to change in the contact.
 	 *
-	 * @return String Contact ID
+	 * @param aChange
+	 *           Items to change in the contact.
 	 */
-	public java.lang.String getId() {
-		return id;
+	public void setChange(EPPContactAddChange aChange) {
+		this.change = aChange;
+
+		if (this.change != null) {
+			this.change.setMode(EPPContactAddChange.MODE_CHANGE);
+		}
 	}
 
-	// End EPPContactUpdateCmd.getId()
+	/**
+	 * Returns {@code true} if remove exists.
+	 *
+	 * @return {@code true} if remove exists; otherwise {@code false}.
+	 */
+	public boolean hasRemove() {
+		return (this.remove != null);
+	}
 
 	/**
-	 * Gets the items to remove to the contact.
+	 * Gets the items to remove from the contact.
 	 *
-	 * @return Object that contains the list of elements to remove to the contact
-	 *         if defined; <code>null</code> otherwise.
+	 * @return Items to remove from the contact if defined; {@code null}
+	 *         otherwise.
 	 */
 	public EPPContactAddChange getRemove() {
-		return remove;
+		return this.remove;
 	}
 
-	// End EPPContactUpdateCmd.getRemove()
-
 	/**
-	 * Sets the items to add to the contact.
+	 * Sets the items to remove from the contact.
 	 *
-	 * @param newAdd
-	 *           Object that contains the list of elements to add to the contact.
+	 * @param aRemove
+	 *           Items to remove from the contact.
 	 */
-	public void setAdd(EPPContactAddChange newAdd) {
-		add = newAdd;
+	public void setRemove(EPPContactAddChange aRemove) {
+		this.remove = aRemove;
 
-		if (add != null) {
-			add.setMode(EPPContactAddChange.MODE_ADD);
+		if (this.remove != null) {
+			this.remove.setMode(EPPContactAddChange.MODE_REMOVE);
 		}
 	}
 
-	// End EPPContactUpdateCmd.setAdd(EPPContactAddChange)
-
-	/**
-	 * Sets the items to change to the contact.
-	 *
-	 * @param newChange
-	 *           Object that contains the list of elements to change to the
-	 *           contact.
-	 */
-	public void setChange(EPPContactAddChange newChange) {
-		change = newChange;
-
-		if (change != null) {
-			change.setMode(EPPContactAddChange.MODE_CHANGE);
-		}
-	}
-
-	// End EPPContactUpdateCmd.setChange(EPPContactAddChange)
-
-	/**
-	 * Set contact id.
-	 *
-	 * @param newId
-	 *           String
-	 */
-	public void setId(String newId) {
-		id = newId;
-	}
-
-	// End EPPContactUpdateCmd.setId(String)
-
-	/**
-	 * Sets the items to remove to the contact.
-	 *
-	 * @param newRemove
-	 *           Object that contains the list of elements to remove to the
-	 *           contact.
-	 */
-	public void setRemove(EPPContactAddChange newRemove) {
-		remove = newRemove;
-
-		if (remove != null) {
-			remove.setMode(EPPContactAddChange.MODE_REMOVE);
-		}
-	}
-
-	// End EPPContactUpdateCmd.setRemove(EPPContactAddChange)
 }
