@@ -209,7 +209,6 @@ public class EPPContactTst extends TestCase {
 		printEnd("contactCheck");
 	}
 
-	// End EPPContactTst.contactCheck()
 
 	/**
 	 * Unit test of <code>EPPContact.sendInfo</code>.
@@ -336,7 +335,6 @@ public class EPPContactTst extends TestCase {
 		printEnd("contactInfo");
 	}
 
-	// End EPPContactTst.contactInfo()
 
 	/**
 	 * Unit test of <code>EPPContact.sendCreate</code>.
@@ -425,7 +423,6 @@ public class EPPContactTst extends TestCase {
 		printEnd("contactCreate");
 	}
 
-	// End EPPContactTst.contactCreate()
 
 	/**
 	 * Unit test of <code>EPPContact.sendDelete</code>.
@@ -455,7 +452,6 @@ public class EPPContactTst extends TestCase {
 		printEnd("contactDelete");
 	}
 
-	// End EPPContactTst.contactDelete()
 
 	/**
 	 * Unit test of <code>EPPContact.sendUpdate</code>.
@@ -469,7 +465,7 @@ public class EPPContactTst extends TestCase {
 
 		try {
 			System.out.println("\n----------------------------------------------------------------");
-			System.out.println("\ncontactDelete: Contact update for " + theName);
+			System.out.println("\ncontactUpdate: Contact update for " + theName);
 			contact.setTransId("ABC-12345-XYZ");
 			contact.addContactId(theName);
 
@@ -521,7 +517,6 @@ public class EPPContactTst extends TestCase {
 		printEnd("contactUpdate");
 	}
 
-	// End EPPContactTst.contactUpdate()
 
 	/**
 	 * Unit test of <code>EPPContact.sendTransfer</code> for a transfer query.
