@@ -19,11 +19,6 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
 ***********************************************************/
 package com.verisign.epp.codec.defReg;
 
-import org.w3c.dom.Document;
-
-// W3C Imports
-import org.w3c.dom.Element;
-
 //----------------------------------------------
 //
 // imports...
@@ -32,8 +27,17 @@ import org.w3c.dom.Element;
 // Java Core Imports
 import java.util.Date;
 
+import org.w3c.dom.Document;
+// W3C Imports
+import org.w3c.dom.Element;
+
 // EPP Imports
-import com.verisign.epp.codec.gen.*;
+import com.verisign.epp.codec.gen.EPPCodecException;
+import com.verisign.epp.codec.gen.EPPDecodeException;
+import com.verisign.epp.codec.gen.EPPEncodeException;
+import com.verisign.epp.codec.gen.EPPResponse;
+import com.verisign.epp.codec.gen.EPPTransId;
+import com.verisign.epp.codec.gen.EPPUtil;
 
 
 /**
