@@ -19,13 +19,7 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
 ***********************************************************/
 package com.verisign.epp.codec.emailFwd;
 
-import org.w3c.dom.Document;
-
-// W3C Imports
-import org.w3c.dom.Element;
-
 import java.util.Date;
-
 //----------------------------------------------
 //
 // imports...
@@ -34,8 +28,19 @@ import java.util.Date;
 // Java Core Imports
 import java.util.Vector;
 
+import org.w3c.dom.Document;
+// W3C Imports
+import org.w3c.dom.Element;
+
 // EPP Imports
-import com.verisign.epp.codec.gen.*;
+import com.verisign.epp.codec.gen.EPPAuthInfo;
+import com.verisign.epp.codec.gen.EPPCodecException;
+import com.verisign.epp.codec.gen.EPPDecodeException;
+import com.verisign.epp.codec.gen.EPPEncodeException;
+import com.verisign.epp.codec.gen.EPPFactory;
+import com.verisign.epp.codec.gen.EPPResponse;
+import com.verisign.epp.codec.gen.EPPTransId;
+import com.verisign.epp.codec.gen.EPPUtil;
 
 
 /**
