@@ -21,7 +21,8 @@ package com.verisign.epp.codec.launch;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
@@ -30,7 +31,6 @@ import com.verisign.epp.codec.gen.EPPDecodeException;
 import com.verisign.epp.codec.gen.EPPEncodeException;
 import com.verisign.epp.codec.gen.EPPUtil;
 import com.verisign.epp.codec.mark.EPPMark;
-import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.EqualityUtil;
 
 /**
@@ -43,10 +43,9 @@ import com.verisign.epp.util.EqualityUtil;
 public class EPPLaunchInfData implements EPPCodecComponent {
 
 	/**
-	 * Log4j category for logging
+	 * Category for logging
 	 */
-	private static Logger cat = Logger.getLogger(EPPLaunchInfData.class
-			.getName(), EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPLaunchInfData.class);
 
 	/**
 	 * Constant for the launch phase info response extension local name
@@ -56,8 +55,7 @@ public class EPPLaunchInfData implements EPPCodecComponent {
 	/**
 	 * Constant for the launch phase info response extension tag
 	 */
-	public static final String ELM_NAME = EPPLaunchExtFactory.NS_PREFIX + ":"
-			+ ELM_LOCALNAME;
+	public static final String ELM_NAME = EPPLaunchExtFactory.NS_PREFIX + ":" + ELM_LOCALNAME;
 
 	/**
 	 * XML local name for the application id
@@ -70,8 +68,8 @@ public class EPPLaunchInfData implements EPPCodecComponent {
 	private static final String ELM_STATUS = "status";
 
 	/**
-	 * The phase during which the application or registration was submitted or
-	 * is associated with.
+	 * The phase during which the application or registration was submitted or is
+	 * associated with.
 	 */
 	EPPLaunchPhase phase;
 
@@ -102,10 +100,10 @@ public class EPPLaunchInfData implements EPPCodecComponent {
 	 * list of marks.
 	 * 
 	 * @param aPhase
-	 *            The phase during which the registration was submitted or is
-	 *            associated with.
+	 *           The phase during which the registration was submitted or is
+	 *           associated with.
 	 * @param aMarks
-	 *            List of marks
+	 *           List of marks
 	 */
 	public EPPLaunchInfData(EPPLaunchPhase aPhase, List<EPPMark> aMarks) {
 		this.phase = aPhase;
@@ -117,10 +115,10 @@ public class EPPLaunchInfData implements EPPCodecComponent {
 	 * an individual mark.
 	 * 
 	 * @param aPhase
-	 *            The phase during which the registration was submitted or is
-	 *            associated with.
+	 *           The phase during which the registration was submitted or is
+	 *           associated with.
 	 * @param aMark
-	 *            An individual mark
+	 *           An individual mark
 	 */
 	public EPPLaunchInfData(EPPLaunchPhase aPhase, EPPMark aMark) {
 		this.phase = aPhase;
@@ -132,15 +130,14 @@ public class EPPLaunchInfData implements EPPCodecComponent {
 	 * application identifier, and application status values.
 	 * 
 	 * @param aPhase
-	 *            The phase during which the application was submitted or is
-	 *            associated with.
+	 *           The phase during which the application was submitted or is
+	 *           associated with.
 	 * @param aApplicationId
-	 *            Application identifier of the returned application
+	 *           Application identifier of the returned application
 	 * @param aStatus
-	 *            Status of the launch application
+	 *           Status of the launch application
 	 */
-	public EPPLaunchInfData(EPPLaunchPhase aPhase, String aApplicationId,
-			EPPLaunchStatus aStatus) {
+	public EPPLaunchInfData(EPPLaunchPhase aPhase, String aApplicationId, EPPLaunchStatus aStatus) {
 		this.phase = aPhase;
 		this.applicationId = aApplicationId;
 		this.status = aStatus;
@@ -151,17 +148,17 @@ public class EPPLaunchInfData implements EPPCodecComponent {
 	 * application identifier, application status, and list of marks values.
 	 * 
 	 * @param aPhase
-	 *            The phase during which the application was submitted or is
-	 *            associated with.
+	 *           The phase during which the application was submitted or is
+	 *           associated with.
 	 * @param aApplicationId
-	 *            Application identifier of the returned application
+	 *           Application identifier of the returned application
 	 * @param aStatus
-	 *            Status of the launch application
+	 *           Status of the launch application
 	 * @param aMarks
-	 *            List of marks
+	 *           List of marks
 	 */
-	public EPPLaunchInfData(EPPLaunchPhase aPhase, String aApplicationId,
-			EPPLaunchStatus aStatus, List<EPPMark> aMarks) {
+	public EPPLaunchInfData(EPPLaunchPhase aPhase, String aApplicationId, EPPLaunchStatus aStatus,
+	      List<EPPMark> aMarks) {
 		this.phase = aPhase;
 		this.applicationId = aApplicationId;
 		this.status = aStatus;
@@ -174,17 +171,16 @@ public class EPPLaunchInfData implements EPPCodecComponent {
 	 * values.
 	 * 
 	 * @param aPhase
-	 *            The phase during which the application was submitted or is
-	 *            associated with.
+	 *           The phase during which the application was submitted or is
+	 *           associated with.
 	 * @param aApplicationId
-	 *            Application identifier of the returned application
+	 *           Application identifier of the returned application
 	 * @param aStatus
-	 *            Status of the launch application
+	 *           Status of the launch application
 	 * @param aMark
-	 *            An individual mark
+	 *           An individual mark
 	 */
-	public EPPLaunchInfData(EPPLaunchPhase aPhase, String aApplicationId,
-			EPPLaunchStatus aStatus, EPPMark aMark) {
+	public EPPLaunchInfData(EPPLaunchPhase aPhase, String aApplicationId, EPPLaunchStatus aStatus, EPPMark aMark) {
 		this.phase = aPhase;
 		this.applicationId = aApplicationId;
 		this.status = aStatus;
@@ -196,7 +192,7 @@ public class EPPLaunchInfData implements EPPCodecComponent {
 	 * 
 	 * @return clone of <code>EPPLaunchInfData</code>
 	 * @exception CloneNotSupportedException
-	 *                standard Object.clone exception
+	 *               standard Object.clone exception
 	 */
 	public Object clone() throws CloneNotSupportedException {
 
@@ -233,35 +229,31 @@ public class EPPLaunchInfData implements EPPCodecComponent {
 	 * Sets all this instance's data in the given XML document
 	 * 
 	 * @param aDocument
-	 *            a DOM Document to attach data to.
+	 *           a DOM Document to attach data to.
 	 * @return The root element of this component.
 	 * 
 	 * @throws EPPEncodeException
-	 *             Thrown if any errors prevent encoding.
+	 *            Thrown if any errors prevent encoding.
 	 */
 	public Element encode(Document aDocument) throws EPPEncodeException {
 
 		if (aDocument == null) {
-			throw new EPPEncodeException("aDocument is null"
-					+ " on in EPPLaunchInfData.encode(Document)");
+			throw new EPPEncodeException("aDocument is null" + " on in EPPLaunchInfData.encode(Document)");
 		}
 
 		// Required phase attribute not set?
 		if (this.phase == null) {
-			throw new EPPEncodeException(
-					"EPPLaunchInfData phase attribute must be set.");
+			throw new EPPEncodeException("EPPLaunchInfData phase attribute must be set.");
 		}
 
-		Element root = aDocument.createElementNS(EPPLaunchExtFactory.NS,
-				ELM_NAME);
+		Element root = aDocument.createElementNS(EPPLaunchExtFactory.NS, ELM_NAME);
 
 		// Phase
 		EPPUtil.encodeComp(aDocument, root, this.phase);
 
 		// Application Id
-		EPPUtil.encodeString(aDocument, root, this.applicationId,
-				EPPLaunchExtFactory.NS, EPPLaunchExtFactory.NS_PREFIX + ":"
-						+ ELM_APPLICATION_ID);
+		EPPUtil.encodeString(aDocument, root, this.applicationId, EPPLaunchExtFactory.NS,
+		      EPPLaunchExtFactory.NS_PREFIX + ":" + ELM_APPLICATION_ID);
 
 		// Status
 		EPPUtil.encodeComp(aDocument, root, this.status);
@@ -275,49 +267,44 @@ public class EPPLaunchInfData implements EPPCodecComponent {
 	/**
 	 * Decode the EPPLaunchInfData component
 	 * 
-	 * @param aElement Element to decode from
-	 * @throws EPPDecodeException On decoding error
+	 * @param aElement
+	 *           Element to decode from
+	 * @throws EPPDecodeException
+	 *            On decoding error
 	 */
 	public void decode(Element aElement) throws EPPDecodeException {
 
 		// Phase
-		this.phase = (EPPLaunchPhase) EPPUtil.decodeComp(aElement,
-				EPPLaunchExtFactory.NS, EPPLaunchPhase.ELM_NAME,
-				EPPLaunchPhase.class);
+		this.phase = (EPPLaunchPhase) EPPUtil.decodeComp(aElement, EPPLaunchExtFactory.NS, EPPLaunchPhase.ELM_NAME,
+		      EPPLaunchPhase.class);
 
 		if (this.phase == null) {
-			throw new EPPDecodeException(
-					"EPPLaunchInfo phase element not found.");
+			throw new EPPDecodeException("EPPLaunchInfo phase element not found.");
 		}
 
 		// Application Id
-		this.applicationId = EPPUtil.decodeString(aElement,
-				EPPLaunchExtFactory.NS, ELM_APPLICATION_ID);
+		this.applicationId = EPPUtil.decodeString(aElement, EPPLaunchExtFactory.NS, ELM_APPLICATION_ID);
 
 		// Status
-		this.status = (EPPLaunchStatus) EPPUtil.decodeComp(aElement,
-				EPPLaunchExtFactory.NS, EPPLaunchStatus.ELM_NAME,
-				EPPLaunchStatus.class);
+		this.status = (EPPLaunchStatus) EPPUtil.decodeComp(aElement, EPPLaunchExtFactory.NS, EPPLaunchStatus.ELM_NAME,
+		      EPPLaunchStatus.class);
 
 		// Marks
-		this.marks = EPPUtil.decodeCompList(aElement, EPPMark.NS,
-				EPPMark.ELM_NAME, EPPMark.class);
+		this.marks = EPPUtil.decodeCompList(aElement, EPPMark.NS, EPPMark.ELM_NAME, EPPMark.class);
 	}
 
 	/**
 	 * implements a deep <code>EPPLaunchInfData</code> compare.
 	 * 
 	 * @param aObject
-	 *            <code>EPPLaunchInfData</code> instance to compare with
+	 *           <code>EPPLaunchInfData</code> instance to compare with
 	 * 
 	 * @return true if equal false otherwise
 	 */
 	public boolean equals(Object aObject) {
 
 		if (!(aObject instanceof EPPLaunchInfData)) {
-			cat.error("EPPLaunchInfData.equals(): "
-					+ aObject.getClass().getName()
-					+ " not EPPLaunchInfData instance");
+			cat.error("EPPLaunchInfData.equals(): " + aObject.getClass().getName() + " not EPPLaunchInfData instance");
 
 			return false;
 		}
@@ -365,7 +352,7 @@ public class EPPLaunchInfData implements EPPCodecComponent {
 	 * Sets the application identifier of the launch application.
 	 * 
 	 * @param aApplicationId
-	 *            Application identifier of the launch application
+	 *           Application identifier of the launch application
 	 */
 	public void setApplicationId(String aApplicationId) {
 		this.applicationId = aApplicationId;
@@ -387,8 +374,8 @@ public class EPPLaunchInfData implements EPPCodecComponent {
 	 * or is associated with.
 	 * 
 	 * @param aPhase
-	 *            Phase during which the application or registration was
-	 *            submitted or is associated with
+	 *           Phase during which the application or registration was submitted
+	 *           or is associated with
 	 */
 	public void setPhase(EPPLaunchPhase aPhase) {
 		this.phase = aPhase;
@@ -407,19 +394,19 @@ public class EPPLaunchInfData implements EPPCodecComponent {
 	 * Sets the application status.
 	 * 
 	 * @param aStatus
-	 *            The application status
+	 *           The application status
 	 */
 	public void setStatus(EPPLaunchStatus aStatus) {
 		this.status = aStatus;
 	}
-	
+
 	/**
 	 * Sets the status with one of the <code>EPPLaunchStatus</code>
 	 * <code>STATUS</code> constants.
 	 * 
 	 * @param aStatusString
-	 *            One of the <code>EPPLaunchStatus</code> <code>STATUS</code>
-	 *            constants.
+	 *           One of the <code>EPPLaunchStatus</code> <code>STATUS</code>
+	 *           constants.
 	 */
 	public void setStatus(String aStatusString) {
 		if (aStatusString == null) {
@@ -429,26 +416,24 @@ public class EPPLaunchInfData implements EPPCodecComponent {
 			this.status = new EPPLaunchStatus(aStatusString);
 		}
 	}
-	
-	
+
 	/**
 	 * Sets the phase with one of the <code>EPPLaunchPhase</code>
 	 * <code>PHASE</code> constants.
 	 * 
 	 * @param aPhaseString
-	 *            One of the <code>EPPLaunchPhase</code> <code>PHASE</code>
-	 *            constants.
+	 *           One of the <code>EPPLaunchPhase</code> <code>PHASE</code>
+	 *           constants.
 	 */
 	public void setPhase(String aPhaseString) {
 		this.phase = new EPPLaunchPhase(aPhaseString);
 	}
-	
 
 	/**
 	 * Sets an individual mark.
 	 * 
 	 * @param aMark
-	 *            An individual mark
+	 *           An individual mark
 	 */
 	public void setMark(EPPMark aMark) {
 		this.marks = new ArrayList<EPPMark>();
@@ -469,11 +454,12 @@ public class EPPLaunchInfData implements EPPCodecComponent {
 			return this.marks.get(0);
 		}
 	}
-	
+
 	/**
 	 * Add a mark to the list of marks.
 	 * 
-	 * @param aMark Mark to add to list
+	 * @param aMark
+	 *           Mark to add to list
 	 */
 	public void addMark(EPPMark aMark) {
 		if (this.marks == null) {
@@ -495,7 +481,7 @@ public class EPPLaunchInfData implements EPPCodecComponent {
 	 * Sets the list of marks.
 	 * 
 	 * @param aMarks
-	 *            List of marks
+	 *           List of marks
 	 */
 	public void setMarks(List<EPPMark> aMarks) {
 		this.marks = aMarks;
@@ -506,17 +492,18 @@ public class EPPLaunchInfData implements EPPCodecComponent {
 	 * indented XML <code>String</code> representation of the concrete
 	 * <code>EPPCodecComponent</code>.
 	 *
-	 * @return Indented XML <code>String</code> if successful;
-	 * 		   <code>ERROR</code> otherwise.
+	 * @return Indented XML <code>String</code> if successful; <code>ERROR</code>
+	 *         otherwise.
 	 */
 	public String toString() {
 		return EPPUtil.toString(this);
 	}
 
 	/**
-	 * Returns the XML namespace associated with the <code>EPPCodecComponent</code>.
+	 * Returns the XML namespace associated with the
+	 * <code>EPPCodecComponent</code>.
 	 * 
-	 * @return XML namespace for the <code>EPPCodecComponent</code>. 
+	 * @return XML namespace for the <code>EPPCodecComponent</code>.
 	 */
 	@Override
 	public String getNamespace() {
