@@ -20,6 +20,23 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
 
 package com.verisign.epp.interfaces;
 
+// Java Core Imports
+import java.util.Enumeration;
+import java.util.Random;
+
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
+// EPP Imports
+import com.verisign.epp.codec.gen.EPPResponse;
+import com.verisign.epp.codec.host.EPPHostAddress;
+import com.verisign.epp.codec.host.EPPHostCheckResp;
+import com.verisign.epp.codec.host.EPPHostCheckResult;
+import com.verisign.epp.codec.host.EPPHostInfoResp;
+import com.verisign.epp.codec.namestoreext.EPPNamestoreExtNamestoreExt;
+import com.verisign.epp.util.Environment;
+import com.verisign.epp.util.TestThread;
+
 //----------------------------------------------
 //
 // imports...
@@ -27,27 +44,10 @@ package com.verisign.epp.interfaces;
 //----------------------------------------------
 
 // JUNIT Imports
-import junit.framework.*;
-
-// Log4j imports
-import org.apache.log4j.*;
-
-// Java Core Imports
-import java.util.Enumeration;
-import java.util.Random;
-
-// EPP Imports
-import com.verisign.epp.codec.gen.EPPResponse;
-import com.verisign.epp.codec.host.*;
-import com.verisign.epp.codec.namestoreext.*;
-
-import com.verisign.epp.interfaces.EPPApplicationSingle;
-import com.verisign.epp.interfaces.EPPCommandException;
-import com.verisign.epp.interfaces.EPPHost;
-import com.verisign.epp.interfaces.EPPSession;
-import com.verisign.epp.util.EPPCatFactory;
-import com.verisign.epp.util.Environment;
-import com.verisign.epp.util.TestThread;
+import junit.framework.Assert;
+import junit.framework.Test;
+import junit.framework.TestCase;
+import junit.framework.TestSuite;
 
 /**
  * Is a unit test of the EPPSession class. The unit test will initialize a
@@ -85,8 +85,7 @@ public class EPPNamestoreExtHostTst extends TestCase {
 	private static String configFileName = "epp.config";
 
 	/** Logging category */
-	private static final Logger cat = Logger.getLogger(EPPNamestoreExtHostTst.class.getName(),
-	      EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPNamestoreExtHostTst.class);
 
 	/** EPP Host associated with test */
 	private EPPHost host = null;
