@@ -19,39 +19,24 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
 ***********************************************************/
 package com.verisign.epp.interfaces;
 
-// JUNIT Imports
-import junit.framework.*;
-
-// Log4j imports
-import org.apache.log4j.*;
-
-//----------------------------------------------
-//
-// imports...
-//
-//----------------------------------------------
-// Java Core Imports
-import java.util.GregorianCalendar;
 import java.util.Random;
-import java.util.Vector;
-import java.util.Date;
 
-import com.verisign.epp.codec.domain.*;
-import com.verisign.epp.codec.gen.EPPFactory;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
 import com.verisign.epp.codec.gen.EPPResponse;
 import com.verisign.epp.codec.gen.EPPResult;
-
-import com.verisign.epp.codec.lowbalancepoll.*;
-
-// EPP Imports
-import com.verisign.epp.interfaces.EPPApplicationSingle;
-import com.verisign.epp.interfaces.EPPCommandException;
-import com.verisign.epp.interfaces.EPPDomain;
+import com.verisign.epp.codec.lowbalancepoll.EPPLowBalancePollResponse;
 import com.verisign.epp.transport.EPPClientCon;
-import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.Environment;
 import com.verisign.epp.util.TestThread;
 
+// JUNIT Imports
+import junit.framework.Assert;
+import junit.framework.Test;
+import junit.framework.TestCase;
+import junit.framework.TestSuite;
+
 /**
  * Is a unit test of the <code>EPPDomain</code> class with Domain Create, inf
  * data and report extensions.
@@ -87,8 +72,7 @@ public class EPPLowBalanceDomainTst extends TestCase {
 	private static String configFileName = "epp.config";
 
 	/** Logging category */
-	private static final Logger cat = Logger.getLogger(EPPLowBalanceDomainTst.class.getName(),
-	      EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPLowBalanceDomainTst.class);
 
 	/** EPP Domain associated with test */
 	private EPPDomain domain = null;
