@@ -23,7 +23,8 @@ package com.verisign.epp.codec.registry;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
@@ -62,7 +63,7 @@ import com.verisign.epp.codec.gen.EPPUtil;
 public class EPPRegistryZoneList implements EPPCodecComponent {
 	private static final long serialVersionUID = 6046461410231870288L;
 
-	private static Logger cat = Logger.getLogger(EPPRegistryZoneList.class);
+	private static Logger cat =  LoggerFactory.getLogger(EPPRegistryZoneList.class);
 
 	/** XML Element Name of <code>EPPRegistryZoneList</code> root element. */
 	final static String ELM_NAME = "registry:zoneList";
@@ -259,4 +260,15 @@ public class EPPRegistryZoneList implements EPPCodecComponent {
 		}
 		this.zoneList.add(zone);
 	}
+	
+	/**
+	 * Returns the XML namespace associated with the <code>EPPCodecComponent</code>.
+	 * 
+	 * @return XML namespace for the <code>EPPCodecComponent</code>. 
+	 */
+	@Override
+	public String getNamespace() {
+		return EPPRegistryMapFactory.NS;
+	}
+	
 }
