@@ -21,7 +21,8 @@ package com.verisign.epp.codec.registry.v02;
 
 import java.security.InvalidParameterException;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.Text;
@@ -30,7 +31,6 @@ import com.verisign.epp.codec.gen.EPPCodecComponent;
 import com.verisign.epp.codec.gen.EPPDecodeException;
 import com.verisign.epp.codec.gen.EPPEncodeException;
 import com.verisign.epp.codec.gen.EPPUtil;
-import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.EqualityUtil;
 
 /**
@@ -50,8 +50,8 @@ public class EPPRegistryBatchSchedule implements EPPCodecComponent {
 	/**
 	 * Logger
 	 */
-	private static Logger cat = Logger.getLogger(EPPRegistryBatchSchedule.class.getName(),
-	      EPPCatFactory.getInstance().getFactory());
+	    private static Logger cat = LoggerFactory.getLogger(EPPRegistryBatchSchedule.class);
+	      
 
 	/**
 	 * Possible values for the {@code frequency} attribute.
