@@ -21,7 +21,8 @@ package com.verisign.epp.codec.registry.v02;
 
 import java.security.InvalidParameterException;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
@@ -86,9 +87,9 @@ import com.verisign.epp.util.EqualityUtil;
 public class EPPRegistryContact implements EPPCodecComponent {
 
 	/**
-	 * Log4j category for logging
+	 * Category for logging
 	 */
-	private static Logger cat = Logger.getLogger(EPPRegistryContact.class);
+	private static Logger cat =  LoggerFactory.getLogger(EPPRegistryContact.class);
 
 	/**
 	 * Possible values for the {@code sharePolicy} attribute.
