@@ -23,7 +23,8 @@ package com.verisign.epp.codec.registry.v02;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
@@ -32,7 +33,7 @@ import com.verisign.epp.codec.gen.EPPCodecException;
 import com.verisign.epp.codec.gen.EPPDecodeException;
 import com.verisign.epp.codec.gen.EPPEncodeException;
 import com.verisign.epp.codec.gen.EPPUtil;
-import com.verisign.epp.util.EPPCatFactory;
+
 
 /**
  * This class holds a {@code List} of supported status used in
@@ -48,8 +49,8 @@ public class EPPRegistrySupportedStatus implements EPPCodecComponent {
 	/**
 	 * Logger
 	 */
-	private static Logger cat = Logger.getLogger(EPPRegistrySupportedStatus.class.getName(),
-	      EPPCatFactory.getInstance().getFactory());
+	    private static Logger cat = LoggerFactory.getLogger(EPPRegistrySupportedStatus.class);
+	      
 
 	/**
 	 * XML local name for {@code EPPRegistrySupportedStatus}.
