@@ -30,7 +30,8 @@ import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Random;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.verisign.epp.codec.gen.EPPResponse;
 import com.verisign.epp.codec.registry.v02.EPPRegistryBatchJob;
@@ -88,7 +89,7 @@ import com.verisign.epp.codec.registry.v02.EPPRegistryZoneName;
 import com.verisign.epp.interfaces.EPPApplicationSingle;
 import com.verisign.epp.interfaces.EPPCommandException;
 import com.verisign.epp.interfaces.EPPSession;
-import com.verisign.epp.util.EPPCatFactory;
+
 import com.verisign.epp.util.Environment;
 import com.verisign.epp.util.TestThread;
 
@@ -112,8 +113,8 @@ public class EPPRegistryTst extends TestCase {
 	/**
 	 * Logging category
 	 */
-	private static final Logger cat = Logger.getLogger(EPPRegistryTst.class.getName(),
-	      EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPRegistryTst.class);
+	      
 
 	/**
 	 * EPP Registry associated with test
