@@ -21,10 +21,10 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
 package com.verisign.epp.codec.relateddomainext;
 
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.List;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
@@ -33,7 +33,7 @@ import com.verisign.epp.codec.gen.EPPCodecException;
 import com.verisign.epp.codec.gen.EPPDecodeException;
 import com.verisign.epp.codec.gen.EPPEncodeException;
 import com.verisign.epp.codec.gen.EPPUtil;
-import com.verisign.epp.util.EPPCatFactory;
+
 
 /**
  * EPPCodecComponent that encodes and decodes a &lt;relDom:delete&gt; tag associated
@@ -57,10 +57,9 @@ public class EPPRelatedDomainExtDelete implements EPPCodecComponent {
 	private static final long serialVersionUID = 7097759695930056421L;
 
 	/**
-	 * Log4j category for logging
+	 * Category for logging
 	 */
-	private static Logger cat = Logger.getLogger( EPPRelatedDomainExtDelete.class
-			.getName(), EPPCatFactory.getInstance().getFactory() );
+	private static Logger cat = LoggerFactory.getLogger(EPPRelatedDomainExtDelete.class);
 
 	/**
 	 * Element tag name for create
