@@ -31,7 +31,8 @@ import junit.framework.Test;
 import junit.framework.TestCase;
 import junit.framework.TestSuite;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.verisign.epp.codec.domain.EPPDomainCreateResp;
 import com.verisign.epp.codec.domain.EPPDomainInfoCmd;
@@ -56,7 +57,7 @@ import com.verisign.epp.codec.relateddomainext.EPPRelatedDomainExtRenewResp;
 import com.verisign.epp.codec.relateddomainext.EPPRelatedDomainExtTransfer;
 import com.verisign.epp.codec.relateddomainext.EPPRelatedDomainExtTransferResp;
 import com.verisign.epp.codec.relateddomainext.EPPRelatedDomainExtUpdate;
-import com.verisign.epp.util.EPPCatFactory;
+
 import com.verisign.epp.util.Environment;
 import com.verisign.epp.util.TestThread;
 
@@ -927,7 +928,7 @@ public class EPPRelatedDomainTst extends TestCase {
 	 * Logging category
 	 */
 
-	private static final Logger cat = Logger.getLogger(EPPRelatedDomainTst.class.getName(),
-	      EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPRelatedDomainTst.class);
+	      
 
 } // End class EPPRelatedDomainTst
