@@ -20,16 +20,18 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
 
 package com.verisign.epp.codec.secdnsext.v11;
 
-// W3C Imports
-import org.w3c.dom.*;
-
 // Log4j Imports
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+// W3C Imports
+import org.w3c.dom.Document;
+import org.w3c.dom.Element;
 
-// EPP imports
-import com.verisign.epp.util.*;
-import com.verisign.epp.codec.gen.*;
-import com.verisign.epp.codec.secdnsext.v11.EPPSecDNSExtFactory;
+import com.verisign.epp.codec.gen.EPPCodecComponent;
+import com.verisign.epp.codec.gen.EPPCodecException;
+import com.verisign.epp.codec.gen.EPPDecodeException;
+import com.verisign.epp.codec.gen.EPPEncodeException;
+import com.verisign.epp.codec.gen.EPPUtil;
 
 /**
  * The EPPSecDNSExtDsData is the EPPCodecComponent that knows how to encode and
@@ -54,10 +56,9 @@ import com.verisign.epp.codec.secdnsext.v11.EPPSecDNSExtFactory;
 public class EPPSecDNSExtDsData implements EPPCodecComponent {
 
 	/**
-	 * Log4j category for logging
+	 * Category for logging
 	 */
-	private static Logger cat = Logger.getLogger(EPPSecDNSExtDsData.class
-			.getName(), EPPCatFactory.getInstance().getFactory());
+	private static Logger cat = LoggerFactory.getLogger(EPPSecDNSExtDsData.class);
 
 	/** XML Element Name of <code>EPPSecDNSExtDsData</code> root element. */
 	static final String ELM_NAME = EPPSecDNSExtFactory.NS_PREFIX + ":dsData";
@@ -70,20 +71,17 @@ public class EPPSecDNSExtDsData implements EPPCodecComponent {
 	/**
 	 * The element tag name for algorithm
 	 */
-	private static final String ELM_ALG = EPPSecDNSExtFactory.NS_PREFIX
-			+ ":alg";
+	private static final String ELM_ALG = EPPSecDNSExtFactory.NS_PREFIX + ":alg";
 
 	/**
 	 * The element tag name for digestType
 	 */
-	private static final String ELM_DIGEST_TYPE = EPPSecDNSExtFactory.NS_PREFIX
-			+ ":digestType";
+	private static final String ELM_DIGEST_TYPE = EPPSecDNSExtFactory.NS_PREFIX + ":digestType";
 
 	/**
 	 * The element tag name for digest
 	 */
-	private static final String ELM_DIGEST = EPPSecDNSExtFactory.NS_PREFIX
-			+ ":digest";
+	private static final String ELM_DIGEST = EPPSecDNSExtFactory.NS_PREFIX + ":digest";
 
 	/** Unspecified int */
 	private static final int UNSPEC_INT = -1;
@@ -157,22 +155,22 @@ public class EPPSecDNSExtDsData implements EPPCodecComponent {
 	 * </table>
 	 */
 	public static final int SHA1_DIGEST_TYPE = 1;
-	
+
 	/**
-	 * SHA-256 Digest Type 
+	 * SHA-256 Digest Type
 	 */
 	public static final int SHA256_DIGEST_TYPE = 2;
 
 	/**
-	 * GOST R 34.11-94 
+	 * GOST R 34.11-94
 	 */
 	public static final int GOST3411_DIGEST_TYPE = 3;
-	
+
 	/**
-	 * SHA-384 Digest Type 
+	 * SHA-384 Digest Type
 	 */
 	public static final int SHA384_DIGEST_TYPE = 4;
-	
+
 	/**
 	 * The keyTag field value of this dsData component
 	 */
@@ -208,11 +206,10 @@ public class EPPSecDNSExtDsData implements EPPCodecComponent {
 	 * Create a new instance (copy) of EPPSecDNSExtDsData
 	 * 
 	 * @param dsData
-	 *            <code>EPPSecDNSExtDsData</code> instance
+	 *           <code>EPPSecDNSExtDsData</code> instance
 	 */
 	public EPPSecDNSExtDsData(EPPSecDNSExtDsData dsData) {
-		this(dsData.getKeyTag(), dsData.getAlg(), dsData.getDigestType(),
-				dsData.getDigest(), dsData.getKeyData());
+		this(dsData.getKeyTag(), dsData.getAlg(), dsData.getDigestType(), dsData.getDigest(), dsData.getKeyData());
 
 	}
 
@@ -221,18 +218,17 @@ public class EPPSecDNSExtDsData implements EPPCodecComponent {
 	 * constructor includes all secDNS:dsData elements.
 	 * 
 	 * @param keyTag
-	 *            the keyTag value to use for this instance.
+	 *           the keyTag value to use for this instance.
 	 * @param alg
-	 *            the algorithm value to use for this instance.
+	 *           the algorithm value to use for this instance.
 	 * @param digestType
-	 *            the digestType value to use for this instance.
+	 *           the digestType value to use for this instance.
 	 * @param digest
-	 *            the digest value to use for this instance.
+	 *           the digest value to use for this instance.
 	 * @param keyData
-	 *            the keyData value to use for this instance.
+	 *           the keyData value to use for this instance.
 	 */
-	public EPPSecDNSExtDsData(int keyTag, int alg, int digestType,
-			String digest, EPPSecDNSExtKeyData keyData) {
+	public EPPSecDNSExtDsData(int keyTag, int alg, int digestType, String digest, EPPSecDNSExtKeyData keyData) {
 		setKeyTag(keyTag);
 		setAlg(alg);
 		setDigestType(digestType);
@@ -245,13 +241,13 @@ public class EPPSecDNSExtDsData implements EPPCodecComponent {
 	 * constructor includes only the required secDNS:dsData elements.
 	 * 
 	 * @param keyTag
-	 *            the keyTag value to use for this instance.
+	 *           the keyTag value to use for this instance.
 	 * @param alg
-	 *            the algorithm value to use for this instance.
+	 *           the algorithm value to use for this instance.
 	 * @param digestType
-	 *            the digestType value to use for this instance.
+	 *           the digestType value to use for this instance.
 	 * @param digest
-	 *            the digest value to use for this instance.
+	 *           the digest value to use for this instance.
 	 */
 	public EPPSecDNSExtDsData(int keyTag, int alg, int digestType, String digest) {
 		setKeyTag(keyTag);
@@ -266,8 +262,8 @@ public class EPPSecDNSExtDsData implements EPPCodecComponent {
 	 * for the secDNS:update/secDNS:rem extension.
 	 * 
 	 * @param keyTag
-	 *            an <code>int</code> value representing the secDNS:keyTag to
-	 *            use for this instance.
+	 *           an <code>int</code> value representing the secDNS:keyTag to use
+	 *           for this instance.
 	 */
 	public EPPSecDNSExtDsData(int keyTag) {
 		setKeyTag(keyTag);
@@ -279,8 +275,8 @@ public class EPPSecDNSExtDsData implements EPPCodecComponent {
 	 * for the secDNS:update/secDNS:rem extension.
 	 * 
 	 * @param keyTag
-	 *            an <code>Integer</code> instance representing the
-	 *            secDNS:keyTag to use for this instance.
+	 *           an <code>Integer</code> instance representing the secDNS:keyTag
+	 *           to use for this instance.
 	 */
 	public EPPSecDNSExtDsData(Integer keyTag) {
 		setKeyTag(keyTag);
@@ -290,11 +286,11 @@ public class EPPSecDNSExtDsData implements EPPCodecComponent {
 	 * Append all data from this secDNS:dsData to the given DOM Document
 	 * 
 	 * @param aDocument
-	 *            The DOM Document to append data to
-     * @return Encoded DOM <code>Element</code>
+	 *           The DOM Document to append data to
+	 * @return Encoded DOM <code>Element</code>
 	 * @throws EPPEncodeException
-	 *             Thrown when errors occur during the encode attempt or if the
-	 *             instance is invalid.
+	 *            Thrown when errors occur during the encode attempt or if the
+	 *            instance is invalid.
 	 */
 
 	public Element encode(Document aDocument) throws EPPEncodeException {
@@ -304,31 +300,24 @@ public class EPPSecDNSExtDsData implements EPPCodecComponent {
 			validateState();
 		}
 		catch (EPPCodecException e) {
-			cat.error("EPPSecDNSExtDsData.encode(): Invalid state on encode: "
-					+ e);
-			throw new EPPEncodeException("EPPSecDNSExtDsData invalid state: "
-					+ e);
+			cat.error("EPPSecDNSExtDsData.encode(): Invalid state on encode: " + e);
+			throw new EPPEncodeException("EPPSecDNSExtDsData invalid state: " + e);
 		}
 
 		// secDNS:dsData
-		Element root = aDocument.createElementNS(EPPSecDNSExtFactory.NS,
-				ELM_NAME);
+		Element root = aDocument.createElementNS(EPPSecDNSExtFactory.NS, ELM_NAME);
 
 		// secDNS:keyTag
-		EPPUtil.encodeString(aDocument, root, keyTag + "",
-				EPPSecDNSExtFactory.NS, ELM_KEY_TAG);
+		EPPUtil.encodeString(aDocument, root, keyTag + "", EPPSecDNSExtFactory.NS, ELM_KEY_TAG);
 
 		// secDNS:alg
-		EPPUtil.encodeString(aDocument, root, alg + "", EPPSecDNSExtFactory.NS,
-				ELM_ALG);
+		EPPUtil.encodeString(aDocument, root, alg + "", EPPSecDNSExtFactory.NS, ELM_ALG);
 
 		// secDNS:digestType
-		EPPUtil.encodeString(aDocument, root, digestType + "",
-				EPPSecDNSExtFactory.NS, ELM_DIGEST_TYPE);
+		EPPUtil.encodeString(aDocument, root, digestType + "", EPPSecDNSExtFactory.NS, ELM_DIGEST_TYPE);
 
 		// secDNS:digest
-		EPPUtil.encodeString(aDocument, root, digest, EPPSecDNSExtFactory.NS,
-				ELM_DIGEST);
+		EPPUtil.encodeString(aDocument, root, digest, EPPSecDNSExtFactory.NS, ELM_DIGEST);
 
 		// secDNS:pubKey
 		EPPUtil.encodeComp(aDocument, root, keyData);
@@ -341,14 +330,13 @@ public class EPPSecDNSExtDsData implements EPPCodecComponent {
 	 * Element of the DOM tree
 	 * 
 	 * @param aElement
-	 *            The root element of the fragment of XML
+	 *           The root element of the fragment of XML
 	 * @throws EPPDecodeException
-	 *             Thrown if any errors occur during decoding.
+	 *            Thrown if any errors occur during decoding.
 	 */
 	public void decode(Element aElement) throws EPPDecodeException {
 
-		Integer keyTagInt = EPPUtil.decodeInteger(aElement,
-				EPPSecDNSExtFactory.NS, ELM_KEY_TAG);
+		Integer keyTagInt = EPPUtil.decodeInteger(aElement, EPPSecDNSExtFactory.NS, ELM_KEY_TAG);
 		if (keyTagInt == null) {
 			keyTag = UNSPEC_INT;
 		}
@@ -356,8 +344,7 @@ public class EPPSecDNSExtDsData implements EPPCodecComponent {
 			keyTag = keyTagInt.intValue();
 		}
 
-		Integer algInt = EPPUtil.decodeInteger(aElement,
-				EPPSecDNSExtFactory.NS, ELM_ALG);
+		Integer algInt = EPPUtil.decodeInteger(aElement, EPPSecDNSExtFactory.NS, ELM_ALG);
 		if (algInt == null) {
 			alg = UNSPEC_INT;
 		}
@@ -365,8 +352,7 @@ public class EPPSecDNSExtDsData implements EPPCodecComponent {
 			alg = algInt.intValue();
 		}
 
-		Integer digestTypeInt = EPPUtil.decodeInteger(aElement,
-				EPPSecDNSExtFactory.NS, ELM_DIGEST_TYPE);
+		Integer digestTypeInt = EPPUtil.decodeInteger(aElement, EPPSecDNSExtFactory.NS, ELM_DIGEST_TYPE);
 		if (digestTypeInt == null) {
 			digestType = UNSPEC_INT;
 		}
@@ -374,19 +360,17 @@ public class EPPSecDNSExtDsData implements EPPCodecComponent {
 			digestType = digestTypeInt.intValue();
 		}
 
-		setDigest(EPPUtil.decodeString(aElement, EPPSecDNSExtFactory.NS,
-				ELM_DIGEST));
+		setDigest(EPPUtil.decodeString(aElement, EPPSecDNSExtFactory.NS, ELM_DIGEST));
 
-		keyData = (EPPSecDNSExtKeyData) EPPUtil.decodeComp(aElement,
-				EPPSecDNSExtFactory.NS, EPPSecDNSExtKeyData.ELM_NAME,
-				EPPSecDNSExtKeyData.class);
+		keyData = (EPPSecDNSExtKeyData) EPPUtil.decodeComp(aElement, EPPSecDNSExtFactory.NS, EPPSecDNSExtKeyData.ELM_NAME,
+		      EPPSecDNSExtKeyData.class);
 	}
 
 	/**
 	 * implements a deep <code>EPPSecDNSExtDsData</code> compare.
 	 * 
 	 * @param aObject
-	 *            <code>EPPSecDNSExtDsData</code> instance to compare with
+	 *           <code>EPPSecDNSExtDsData</code> instance to compare with
 	 * 
 	 * @return true if equal false otherwise
 	 */
@@ -413,14 +397,12 @@ public class EPPSecDNSExtDsData implements EPPCodecComponent {
 		}
 
 		// digest
-		if (!((digest == null) ? (theComp.digest == null) : digest
-				.equals(theComp.digest))) {
+		if (!((digest == null) ? (theComp.digest == null) : digest.equals(theComp.digest))) {
 			return false;
 		}
 
 		// keyData
-		if (!((keyData == null) ? (theComp.keyData == null) : keyData
-				.equals(theComp.keyData))) {
+		if (!((keyData == null) ? (theComp.keyData == null) : keyData.equals(theComp.keyData))) {
 			return false;
 		}
 
@@ -436,50 +418,42 @@ public class EPPSecDNSExtDsData implements EPPCodecComponent {
 	 * contain the name of the attribute that is not valid.
 	 * 
 	 * @throws EPPCodecException
-	 *             Thrown if the instance is in an invalid state
+	 *            Thrown if the instance is in an invalid state
 	 */
 	void validateState() throws EPPCodecException {
 		// keyTag: required unsignedShort
 		if (keyTag == UNSPEC_ALG) {
-			throw new EPPCodecException(
-					"EPPSecDNSExtDsData required element keyTag is not set");
+			throw new EPPCodecException("EPPSecDNSExtDsData required element keyTag is not set");
 		}
 		else if ((keyTag < MIN_KEY_TAG) && (keyTag > MAX_KEY_TAG)) {
-			throw new EPPCodecException("EPPSecDNSExtDsData keyTag of "
-					+ keyTag + " is out of range, must be between "
-					+ MIN_KEY_TAG + " and " + MAX_KEY_TAG);
+			throw new EPPCodecException("EPPSecDNSExtDsData keyTag of " + keyTag + " is out of range, must be between "
+			      + MIN_KEY_TAG + " and " + MAX_KEY_TAG);
 
 		}
 
 		// alg: required unsignedByte
 		if (alg == UNSPEC_ALG) {
-			throw new EPPCodecException(
-					"EPPSecDNSExtDsData required element alg is not set");
+			throw new EPPCodecException("EPPSecDNSExtDsData required element alg is not set");
 		}
 		else if ((alg < MIN_ALG) && (alg > MAX_ALG)) {
-			throw new EPPCodecException("EPPSecDNSExtDsData alg of " + alg
-					+ " is out of range, must be between " + MIN_ALG + " and "
-					+ MAX_ALG);
+			throw new EPPCodecException(
+			      "EPPSecDNSExtDsData alg of " + alg + " is out of range, must be between " + MIN_ALG + " and " + MAX_ALG);
 
 		}
 
 		// digestType: required unsignedByte
 		if (digestType == UNSPEC_ALG) {
-			throw new EPPCodecException(
-					"EPPSecDNSExtDsData required element digestType is not set");
+			throw new EPPCodecException("EPPSecDNSExtDsData required element digestType is not set");
 		}
-		else if ((digestType < MIN_DIGEST_TYPE)
-				&& (digestType > MAX_DIGEST_TYPE)) {
-			throw new EPPCodecException("EPPSecDNSExtDsData digestType of "
-					+ digestType + " is out of range, must be between "
-					+ MIN_DIGEST_TYPE + " and " + MAX_DIGEST_TYPE);
+		else if ((digestType < MIN_DIGEST_TYPE) && (digestType > MAX_DIGEST_TYPE)) {
+			throw new EPPCodecException("EPPSecDNSExtDsData digestType of " + digestType
+			      + " is out of range, must be between " + MIN_DIGEST_TYPE + " and " + MAX_DIGEST_TYPE);
 
 		}
 
 		// digest: required hexBinary
 		if (digest == null) {
-			throw new EPPCodecException(
-					"EPPSecDNSExtDsData required attribute digest is not set");
+			throw new EPPCodecException("EPPSecDNSExtDsData required attribute digest is not set");
 		}
 		else {
 			// validate hexBinary digest?
@@ -495,7 +469,7 @@ public class EPPSecDNSExtDsData implements EPPCodecComponent {
 	 * @return clone of <code>EPPSecDNSExtDsData</code>
 	 * 
 	 * @exception CloneNotSupportedException
-	 *                standard Object.clone exception
+	 *               standard Object.clone exception
 	 */
 	public Object clone() throws CloneNotSupportedException {
 
@@ -526,7 +500,7 @@ public class EPPSecDNSExtDsData implements EPPCodecComponent {
 	 * Set secDNS:keyTag value
 	 * 
 	 * @param keyTag
-	 *            an <code>int</code> value representing secDNS:keyTag
+	 *           an <code>int</code> value representing secDNS:keyTag
 	 */
 	public void setKeyTag(int keyTag) {
 		this.keyTag = keyTag;
@@ -536,7 +510,7 @@ public class EPPSecDNSExtDsData implements EPPCodecComponent {
 	 * Set secDNS:keyTag value
 	 * 
 	 * @param keyTag
-	 *            an <code>Integer</code> instance representing secDNS:keyTag
+	 *           an <code>Integer</code> instance representing secDNS:keyTag
 	 */
 	public void setKeyTag(Integer keyTag) {
 		if (keyTag == null) {
@@ -562,7 +536,7 @@ public class EPPSecDNSExtDsData implements EPPCodecComponent {
 	 * Set secDNS:alg value
 	 * 
 	 * @param alg
-	 *            an <code>int</code> value representing secDNS:alg
+	 *           an <code>int</code> value representing secDNS:alg
 	 */
 	public void setAlg(int alg) {
 		this.alg = alg;
@@ -582,7 +556,7 @@ public class EPPSecDNSExtDsData implements EPPCodecComponent {
 	 * Set secDNS:digestType value
 	 * 
 	 * @param digestType
-	 *            an <code>int</code> value representing secDNS:digestType
+	 *           an <code>int</code> value representing secDNS:digestType
 	 */
 	public void setDigestType(int digestType) {
 		this.digestType = digestType;
@@ -605,8 +579,8 @@ public class EPPSecDNSExtDsData implements EPPCodecComponent {
 	 * hexBinary as defined by http://www.w3.org/TR/xmlschema-2/#hexBinary
 	 * 
 	 * @param digest
-	 *            an <code>String</code> value representing the hexBinary
-	 *            secDNS:digest
+	 *           an <code>String</code> value representing the hexBinary
+	 *           secDNS:digest
 	 * @see com.verisign.epp.codec.gen.EPPUtil#removeWhitespace(String inString)
 	 */
 	public void setDigest(String digest) {
@@ -629,8 +603,8 @@ public class EPPSecDNSExtDsData implements EPPCodecComponent {
 	 * Set secDNS:keyData value
 	 * 
 	 * @param keyData
-	 *            an <code>EPPSecDNSExtKeyData</code> value representing
-	 *            secDNS:keyData
+	 *           an <code>EPPSecDNSExtKeyData</code> value representing
+	 *           secDNS:keyData
 	 */
 	public void setKeyData(EPPSecDNSExtKeyData keyData) {
 		this.keyData = keyData;
@@ -655,21 +629,22 @@ public class EPPSecDNSExtDsData implements EPPCodecComponent {
 	 * indented XML <code>String</code> representation of the concrete
 	 * <code>EPPCodecComponent</code>.
 	 * 
-	 * @return Indented XML <code>String</code> if successful;
-	 *         <code>ERROR</code> otherwise.
+	 * @return Indented XML <code>String</code> if successful; <code>ERROR</code>
+	 *         otherwise.
 	 */
 	public String toString() {
 		return EPPUtil.toString(this);
 	}
-	
+
 	/**
-	 * Returns the XML namespace associated with the <code>EPPCodecComponent</code>.
+	 * Returns the XML namespace associated with the
+	 * <code>EPPCodecComponent</code>.
 	 * 
-	 * @return XML namespace for the <code>EPPCodecComponent</code>. 
+	 * @return XML namespace for the <code>EPPCodecComponent</code>.
 	 */
 	@Override
 	public String getNamespace() {
 		return EPPSecDNSExtFactory.NS;
 	}
-	
+
 }
\ No newline at end of file
