@@ -20,7 +20,8 @@ package com.verisign.epp.codec.verificationcode;
 
 import java.util.Date;
 
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.Text;
@@ -29,7 +30,6 @@ import com.verisign.epp.codec.gen.EPPCodecComponent;
 import com.verisign.epp.codec.gen.EPPDecodeException;
 import com.verisign.epp.codec.gen.EPPEncodeException;
 import com.verisign.epp.codec.gen.EPPUtil;
-import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.EqualityUtil;
 
 /**
@@ -45,10 +45,10 @@ import com.verisign.epp.util.EqualityUtil;
 public class EPPVerificationCode implements EPPCodecComponent {
 
 	/**
-	 * Log4j category for logging
+	 * Category for logging
 	 */
-	private static Logger cat = Logger.getLogger(EPPVerificationCode.class.getName(),
-	      EPPCatFactory.getInstance().getFactory());
+	    private static Logger cat = LoggerFactory.getLogger(EPPVerificationCode.class);
+	      
 
 	/**
 	 * Constant for the local name
